# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['paz']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'paz',
    'version': '0.1.1',
    'description': 'path manipulation swiss army knife',
    'long_description': "paz\n===\n\n**paz** is a small, versatile library for path string manipulation.\nIt's primary purpose is to simplify path & file management operations\nby wrapping built-in modules like ``os``, ``os.path``, ``shutil``\nin a concise, pythonic api.\n\nusage\n-----\n\n.. code:: python\n\n    from paz import p\n\n    image_dir = p('/home/username/pics')\n    for image_file in image_dir.walk('*.png', type='file'):\n        image_file.move('{basepath}_backup.{ext}')\n\nThe same code without ``paz``:\n\n.. code:: python\n\n    import os\n    import shutil\n\n    for root, dirs, files in os.walk('/home/username/pics'):\n        for file in files:\n            if file.endswith('.png'):\n                basename = os.path.splitext(file)[0]\n                src_path = os.path.join(root, file)\n                dst_path = os.path.join(root, basename + '_backup.png')\n                shutil.move(src_path, dst_path)\n\ndocs\n----\n\nThe library provides only one function - ``paz.p``.\nIt returns a subclass of ``str``/``bytes``, depending on the input,\nwhich can be manipulated like a regular string.\nOn top of that, an instance provides a few commonly used operations:\n\n* file system information: ``owner``, ``group``, ``is_dir``, ``is_file``,\n  ``is_link``, ``exists``, ``type``, ``last_accessed``, ``last_modified``\n* path parts extraction: ``filename``, ``basename``, ``ext``, ``dirname``,\n  ``basepath``, ``path``, ``fullpath``\n* utility operations: ``copy()``, ``move()``, ``chown()``, ``chmod()``, ``hash()``\n* path string manipulation: ``pathmap()`` & readable path joins (ex.: ``image_dir / 'wallpapers'``)\n\n``pathmap``, ``copy`` & ``move`` support substituting path parts between ``{`` and ``}``\nwith the corresponding values. The full diagram of path parts is provided below:\n\n.. code:: text\n\n    /home/username/pics/portrait-of-madame-x.png\n\n    └────────┬────────┘ └─────────┬────────┘ └┬┘\n          dirname              basename      ext\n                        └───────────┬──────────┘\n                                filename\n    └───────────────────┬──────────────────┘\n                    basepath\n    └──────────────────────┬───────────────────┘\n                         path\n\n\ntests\n-----\n\n.. image:: https://travis-ci.org/nkanaev/paz.svg?branch=master\n    :target: https://travis-ci.org/nkanaev/paz\n",
    'author': 'Nazar Kanaev',
    'author_email': 'nkanaev@live.com',
    'url': 'https://github.com/nkanaev/paz',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.4,<4.0',
}


setup(**setup_kwargs)
